@@ -244,20 +244,23 @@ pool_setall_node_to_be_sent(POOL_QUERY_CONTEXT * query_context)
 			{
 				/*
 				 * If load balance mode is disabled, only send to the primary node.
-				 * or send to the main node if primary node does not exist.
+				 * If primary node does not exist, send to the main node.
 				 */
 				if (!pool_config->load_balance_mode)
 				{
 					if (i == PRIMARY_NODE_ID ||
 						(PRIMARY_NODE_ID < 0 && MAIN_NODE_ID == i))
+					{
 						query_context->where_to_send[i] = true;
-					break;
+						break;
+					}
+					continue;
 				}
 				else
 					/*
 					 * If the node is not primary node nor load balance node,
-					 * there's no point to send query except statement load
-					 * balance is enabled.
+					 * there's no point to send query except statement level
+					 * load balance is enabled.
 					 */
 					if (!pool_config->statement_level_load_balance &&
 						i != PRIMARY_NODE_ID && i != sc->load_balance_node_id)
@@ -373,7 +376,16 @@ pool_virtual_main_db_node_id(void)
 	sc = pool_get_session_context(true);
 	if (!sc)
 	{
-		return REAL_MAIN_NODE_ID;
+		/*
+		 * We used to return REAL_MAIN_NODE_ID here.  Problem with it is, it
+		 * is possible that REAL_MAIN_NODE_ID could be changed
+		 * anytime. Suppose REAL_MAIN_NODE_ID == my_main_node_id == 1. Then
+		 * due to failback, REAL_MAIN_NODE_ID is changed to 0. Then
+		 * MAIN_CONNECTION(cp) will return NULL and any reference to it will
+		 * cause segmentation fault. To prevent the issue we should return
+		 * my_main_node_id instead.
+		 */
+		return my_main_node_id;
 	}
 
 	if (sc->in_progress && sc->query_context)
@@ -416,7 +428,7 @@ pool_virtual_main_db_node_id(void)
 	}
 
 	/*
-	 * No query context exists.  If in native replication mode, returns primary node
+	 * No query context exists.  If in streaming replication mode, returns primary node
 	 * if exists.  Otherwise returns my_main_node_id, which represents the
 	 * last REAL_MAIN_NODE_ID.
 	 */
