@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2025	PgPool Global Development Group
+ * Copyright (c) 2003-2024	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -112,8 +112,8 @@ CommandComplete(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend, bool
 				if (session_context->query_context &&
 					session_context->query_context->parse_tree &&
 					is_start_transaction_query(session_context->query_context->parse_tree))
-				{
 					TSTATE(backend, i) = 'T';	/* we are inside a transaction */
+				{
 					ereport(DEBUG1,
 							(errmsg("processing command complete"),
 							 errdetail("set transaction state to T")));
@@ -229,19 +229,7 @@ CommandComplete(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend, bool
 			query = session_context->query_context->query_w_hex;
 			node = pool_get_parse_tree();
 			state = TSTATE(backend, MAIN_NODE_ID);
-
-			/*
-			 * If some rows have been fetched by an execute with non 0 row option,
-			 * we do not create cache.
-			 */ 
-			pool_handle_query_cache(backend, query, node, state,
-									session_context->query_context->partial_fetch);
-
-			/*
-			 * CommandComplete guarantees that all rows have been fetched.  We
-			 * can unconditionally set atEnd flag.
-			 */
-			session_context->query_context->atEnd = true;
+			pool_handle_query_cache(backend, query, node, state);
 		}
 	}
 
